TheoremReach class
Constructors
- TheoremReach({required String userId, required String apiKey})
Properties
Methods
-
initialUrl(
) → String -
isSurveyAvailable(
) → Future< bool> - Checks if surveys are available , it return a bool which can be used based on the return value
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onSurveyCompleted(
String inputUrl) → int -
showSurveys(
BuildContext context) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited